export type i18nMap = {
  [key: string]: {
    en: string,
    de: string,
  },
}

let lang = 'de'
const defaultLang = navigator.language ? navigator.language.substr(0, 2) : 'en'

export interface useI18n {
  setLang(lang: string): void
  $t(key: string): string
}

export default (map: i18nMap): useI18n => {
  return {
    setLang: (_lang: string): void => {
      lang = _lang
    },
    $t: (key: string): string => {
      const t = map[key]
      if (!t) {
        return key
      }

      return t[lang] || t[defaultLang] || key
    }
  }
}
